#!/bin/bash

set -e

DIST_DIR="dist"
ZIP_FILE="$DIST_DIR/xsquare.lcdp.4.11.13.14.8.8_release.zip"
XREPORTS_DEB="xreports/xsquare.xreports_3.3.3.6.deb"
XDAC_DEB="xdac/xsquare.xdac_3.4.1.12.deb"
DOCKER_COMPOSE_CMD="docker compose"

echo "Готовим..."
mkdir -p $DIST_DIR

if [ ! -f "$ZIP_FILE" ]; then
    echo "Скачиваю $ZIP_FILE..."
    wget -q -O $ZIP_FILE https://lcdp.xsquare.ru/files/pghs/xsquare.lcdp.v4/xsquare.lcdp.4.11.13.14.8.8_release.zip
else
    echo "$ZIP_FILE уже существует. Пропускаю скачивание."
fi

if [ ! -f "$XREPORTS_DEB" ]; then
    echo "Скачиваю $XREPORTS_DEB..."
    wget -q -O $XREPORTS_DEB https://lcdp.xsquare.ru/files/xreports/rpm_dep/3.3.3.6/xsquare.xreports_3.3.3.6.deb
else
    echo "$XREPORTS_DEB уже существует. Пропускаю скачивание."
fi

if [ ! -f "$XDAC_DEB" ]; then
    echo "Скачиваю $XDAC_DEB..."
    wget -q -O $XDAC_DEB https://lcdp.xsquare.ru/files/xdac/3.4.1.12/xsquare.xdac_3.4.1.12.deb
else
    echo "$XDAC_DEB уже существует. Пропускаю скачивание."
fi

echo "Распаковка..."
unzip -q -o $ZIP_FILE -d $DIST_DIR

echo "Кладу var/www..."
cp -r dist/xsquare.lcdp.4.11.13.14.8.8_release/var/www nginx/www

echo "Кладу usr/local/xsquare.pghs..."
cp -r dist/xsquare.lcdp.4.11.13.14.8.8_release/usr/local/xsquare.pghs/* pghs/

echo "Кладу usr/local/xsquare.xdac..."
cp -r dist/xsquare.lcdp.4.11.13.14.8.8_release/usr/local/xsquare.xdac/* xdac/

echo "Кладу usr/local/xsquare.xrad..."
cp -r dist/xsquare.lcdp.4.11.13.14.8.8_release/usr/local/xsquare.xrad/* xrad/

echo "Кладу db..."
cp -r dist/xsquare.lcdp.4.11.13.14.8.8_release/db/* postgres/db/

echo "Собираю Docker..."
$DOCKER_COMPOSE_CMD up -d --build

echo "Жду PostgreSQL..."
POSTGRES_CONTAINER=$($DOCKER_COMPOSE_CMD ps -q postgres)
while ! docker exec $POSTGRES_CONTAINER pg_isready -U postgres > /dev/null 2>&1; do
    sleep 2
done
echo "PostgreSQL готов."

echo "Настраиваю базу данных..."
docker exec -i $POSTGRES_CONTAINER psql -U xrad_user -d xraddb < $DIST_DIR/xsquare.lcdp.4.11.13.14.8.8_release/db/xraddb.xsquare.pgsql
docker exec -i $POSTGRES_CONTAINER psql -U app_user -d appdb < $DIST_DIR/xsquare.lcdp.4.11.13.14.8.8_release/db/appdb.xsquare.pgsql

echo "Установка завершена!"

echo "localhost:8001 - Демо стенд - XSQUARE - EDU v.4.11"
echo "localhost:8002 - xRad Builder"